@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: MIDI pitches for guitar chord voicings
 
-our $VERSION = '0.0608';
+our $VERSION = '0.0609';
 
 use strict;
 use warnings;
@@ -172,7 +172,7 @@ sub fingering {
             elsif ($p != 0 && $str =~ /0/) {
                 $str = _increment_fingering($str);
             }
-            push @fingering, $str . '-' . $p;
+            push @fingering, $str . '-' . $p if $p >= 0;
         }
     }
 
@@ -211,7 +211,7 @@ MIDI::Chord::Guitar - MIDI pitches for guitar chord voicings
 
 =head1 VERSION
 
-version 0.0608
+version 0.0609
 
 =head1 SYNOPSIS
 
@@ -362,7 +362,7 @@ Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Gene Boggs.
+This software is copyright (c) 2022 by Gene Boggs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
